"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const RuleBuilder_1 = require("../rules/RuleBuilder");
const ValidatorBuilder_1 = require("../ValidatorBuilder");
let data = {
    platform: '',
    os: '',
    // if platform is DESKTOP, can be WINDOWS or LINUX
    programming_lang: '',
};
const validator = ValidatorBuilder_1.validatorBuilder()
    .newRule()
    .withField('platform')
    .validate(RuleBuilder_1.RuleBuilder.isIn.withValues('MOBILE', 'DESKTOP'))
    .validate(RuleBuilder_1.RuleBuilder.required())
    .newRule()
    .withFieldValueConstraint('platform', 'mobile')
    .withField('os')
    .validate(RuleBuilder_1.RuleBuilder.isIn.withValues('ANDROID', 'iOS', 'WINDOWS'))
    .validate(RuleBuilder_1.RuleBuilder.required())
    .withField('programming_lang')
    .validate(RuleBuilder_1.RuleBuilder.composite
    .any()
    .withSubRule(RuleBuilder_1.RuleBuilder.composite
    .all()
    .withSubRule(RuleBuilder_1.RuleBuilder.exactValue.withPathAndValue('os', 'ANDROID'))
    .withSubRule(RuleBuilder_1.RuleBuilder.isIn.withValues('JAVA', 'KOTLIN'))
    .build())
    .withSubRule(RuleBuilder_1.RuleBuilder.composite
    .all()
    .withSubRule(RuleBuilder_1.RuleBuilder.exactValue.withPathAndValue('os', 'iOS'))
    .withSubRule(RuleBuilder_1.RuleBuilder.isIn.withValues('SWIFT', 'OBJECTIVE-C'))
    .build())
    .withSubRule(RuleBuilder_1.RuleBuilder.composite
    .all()
    .withSubRule(RuleBuilder_1.RuleBuilder.exactValue.withPathAndValue('os', 'WINDOWS'))
    .withSubRule(RuleBuilder_1.RuleBuilder.isIn.withValues('C#'))
    .build())
    .build())
    .newRule()
    .withFieldValueConstraint('platform', 'DESKTOP')
    .withField('os')
    .validate(RuleBuilder_1.RuleBuilder.isIn.withValues('WINDOWS', 'LINUX'))
    .withField('programming_lang')
    .validate(RuleBuilder_1.RuleBuilder.composite
    .any()
    .withSubRule(RuleBuilder_1.RuleBuilder.composite
    .all()
    .withSubRule(RuleBuilder_1.RuleBuilder.exactValue.withPathAndValue('os', 'WINDOWS'))
    .withSubRule(RuleBuilder_1.RuleBuilder.isIn.withValues('JAVA', 'C/C++', 'C#'))
    .build())
    .withSubRule(RuleBuilder_1.RuleBuilder.composite
    .all()
    .withSubRule(RuleBuilder_1.RuleBuilder.exactValue.withPathAndValue('os', 'LINUX'))
    .withSubRule(RuleBuilder_1.RuleBuilder.isIn.withValues('JAVA', 'C/C++'))
    .build())
    .build())
    .build();
console.log('========================================');
console.log('DATA: ', data);
console.log('VALIDATION: ', validator.validate(data));
data = { ...data, platform: 'DESKTOP', os: 'LINUX', programming_lang: 'Basic' }; // INVALID: programming_lang must be Java or C/C++
console.log('========================================');
console.log('DATA: ', data);
console.log('VALIDATION: ', validator.validate(data));
data = { ...data, platform: 'DESKTOP', os: 'MACOS', programming_lang: 'Basic' }; // INVALID: os must be WINDOWS or LINUX
console.log('========================================');
console.log('DATA: ', data);
console.log('VALIDATION: ', validator.validate(data));
data = { ...data, platform: 'MOBILE', os: 'iOS', programming_lang: 'Java' }; // INVALID programming_lang must be SWIFT or OBJECTIVE-C
console.log('========================================');
console.log('DATA: ', data);
console.log('VALIDATION: ', validator.validate(data));
data = { ...data, platform: 'MOBILE', os: 'ANDROID', programming_lang: 'Java' }; // VALID
console.log('========================================');
console.log('DATA: ', data);
console.log('VALIDATION: ', validator.validate(data));
//# sourceMappingURL=nestedRulesSample-fluent.js.map