"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const RuleSetFactory_1 = require("../src/RuleSetFactory");
const FieldValueConstraint_1 = require("../src/constraints/FieldValueConstraint");
const RequiredRule_1 = require("../src/rules/RequiredRule");
const MaxLengthRule_1 = require("../src/rules/MaxLengthRule");
const rulesetConfig = {
    constraints: [
        {
            type: FieldValueConstraint_1.NAME,
            path: 'key1.key11.key21',
            value: 'test',
        },
    ],
    fields: {
        'key1.key11.key22': [
            {
                type: RequiredRule_1.NAME,
            },
            {
                type: MaxLengthRule_1.NAME,
                maxlength: 7,
            },
        ],
    },
};
describe('RuleSet', () => {
    it('Should return success', () => {
        const data = {
            key1: {
                key11: {
                    key21: 'test',
                    key22: 'testval',
                },
            },
        };
        const rs = RuleSetFactory_1.RuleSetFactory.create(rulesetConfig);
        expect(rs.shouldEvaluate(data)).toBe(true);
        expect(rs.evaluate('key1.key11.key22', data)).toEqual({ valid: true });
    });
    it('Should not evaluate', () => {
        const data = {
            key1: {
                key11: {
                    key21: 'test1',
                    key22: 'testval',
                },
            },
        };
        const rs = RuleSetFactory_1.RuleSetFactory.create(rulesetConfig);
        expect(rs.shouldEvaluate(data)).toBe(false);
    });
    it('Should return required failed', () => {
        const data = {
            key1: {
                key11: {
                    key21: 'test',
                    key22: '',
                },
            },
        };
        const rs = RuleSetFactory_1.RuleSetFactory.create(rulesetConfig);
        expect(rs.shouldEvaluate(data)).toBe(true);
        expect(rs.evaluate('key1.key11.key22', data)).toEqual({
            message: "Value 'key1.key11.key22' is required",
            field: 'key1.key11.key22',
            valid: false,
        });
    });
    it('Should return value too long', () => {
        const data = {
            key1: {
                key11: {
                    key21: 'test',
                    key22: '0123456789',
                },
            },
        };
        const rs = RuleSetFactory_1.RuleSetFactory.create(rulesetConfig);
        expect(rs.shouldEvaluate(data)).toBe(true);
        expect(rs.evaluate('key1.key11.key22', data)).toEqual({
            message: "Maximum length exceeded for 'key1.key11.key22'",
            field: 'key1.key11.key22',
            valid: false,
        });
    });
});
//# sourceMappingURL=RuleSet.test.js.map